generate_badge: Generates a Binder badge to add to your README
Description
Generates a Binder badge to add to your README
Usage
generate_badge(
path = ".",
branch = "master",
hub = "mybinder.org",
urlpath = "rstudio"
)
Arguments
path
Assumes local folder unless you say otherwise
branch
Default is master but you can pass other branches
hub
mybinder.org (often used synonymously with Binder) is a single deployment of a BinderHub instance, managed by the creators of Binder. It serves as both a public service and a demonstration of the BinderHub technology but it is by no means the only BinderHub in existence. Pangeo (https://binder.pangeo.io/) is another instance of a BinderHub (pass "binder.pangeo.io" to the hub argument) that is hosted by the geoscience community and is free to use for anyone. It is quite likely that other BinderHubs will be available in the future. You can use the `hub` argument to set the BinderHub of your choice. If your organization wants to host one (with additional resources to serve your community), please read through the MyBinder documentation (https://mybinder.readthedocs.io )
urlpath
Defaults to rstudio for a Rstudio server.
Examples
Run this code# NOT RUN {
# generate_badge("/path/to/repo")
# }
Run the code above in your browser using DataLab