Learn R Programming

holepunch (version 0.1.28.9000)

write_apt: Write a list of apt packages

Description

Writes a list of Debian packages that should be installed. Caution: If you have a Dockerfile, this file will be ignored.

Usage

write_apt(path = ".", apt_input = NULL)

Arguments

path

Path to project

apt_input

A list of Debian packages that should be installed. The base image used is usually the latest released version of Ubuntu.

Examples

Run this code
# NOT RUN {
write_apt(
  path = ".",
  apt_input = "
texlive-latex-base
texlive-latex-recommended
texlive-science
texlive-latex-extra
texlive-fonts-recommended
dvipng
ghostscript"
)
# }

Run the code above in your browser using DataLab