Learn R Programming

holepunch (version 0.1.28.9000)

write_requirements: write a list of Python requirements

Description

Writes a list of Debian packages that should be installed. Caution: If you have a Dockerfile, this file will be ignored.

Usage

write_requirements(path = ".", requirements = NULL)

Arguments

path

Path to project

requirements

A list of Python packages that should be installed in your environment.

Examples

Run this code
# NOT RUN {
write_requirements(
  path = ".",
  requirements = "
numpy==1.16.*
matplotlib==3.*
seaborn==0.8.1
"
)
# }

Run the code above in your browser using DataLab