powered by
Writes a list of Debian packages that should be installed. Caution: If you have a Dockerfile, this file will be ignored.
write_apt(path = ".", apt_input = NULL)
Path to project
A list of Debian packages that should be installed. The base image used is usually the latest released version of Ubuntu.
# NOT RUN { write_apt( path = ".", apt_input = " texlive-latex-base texlive-latex-recommended texlive-science texlive-latex-extra texlive-fonts-recommended dvipng ghostscript" ) # }
Run the code above in your browser using DataLab