powered by
Writes a list of Debian packages that should be installed. Caution: If you have a Dockerfile, this file will be ignored.
write_requirements(path = ".", requirements = NULL)
Path to project
A list of Python packages that should be installed in your environment.
# NOT RUN { write_requirements( path = ".", requirements = " numpy==1.16.* matplotlib==3.* seaborn==0.8.1 " ) # }
Run the code above in your browser using DataLab